#ifndef CONFIGWEBENGINEVIEWER_H
#define CONFIGWEBENGINEVIEWER_H

#define WEBENGINEVIEWER_PRINT_SUPPORT 1

#endif
